# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common.proto

import sys

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor.FileDescriptor(
    name="common.proto",
    package="common",
    syntax="proto3",
    serialized_options=_b(
        "\n\037com.shuzhi.pmmlgrpc.pmml.commonB\013CommonProtoP\001\242\002\002CM"
    ),
    serialized_pb=_b(
        '\n\x0c\x63ommon.proto\x12\x06\x63ommon"s\n\x07Request\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0b\n\x03in1\x18\x03 \x01(\t\x12\x0b\n\x03in2\x18\x04 \x01(\t\x12\x0b\n\x03in3\x18\x05 \x01(\t\x12\x0b\n\x03in4\x18\x06 \x01(\t\x12\x0b\n\x03in5\x18\x07 \x01(\t\x12\r\n\x05\x65xtra\x18\x08 \x01(\t"\x82\x01\n\x08Response\x12\x12\n\nrequest_id\x18\x01 \x01(\t\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x0b\n\x03msg\x18\x03 \x01(\t\x12\x0c\n\x04out1\x18\x04 \x01(\t\x12\x0c\n\x04out2\x18\x05 \x01(\t\x12\x0c\n\x04out3\x18\x06 \x01(\t\x12\x0c\n\x04out4\x18\x07 \x01(\t\x12\x0c\n\x04out5\x18\x08 \x01(\t2m\n\x06\x43ommon\x12.\n\x07predict\x12\x0f.common.Request\x1a\x10.common.Response"\x00\x12\x33\n\x0cpredictAsync\x12\x0f.common.Request\x1a\x10.common.Response"\x00\x42\x35\n\x1f\x63om.shuzhi.pmmlgrpc.pmml.commonB\x0b\x43ommonProtoP\x01\xa2\x02\x02\x43Mb\x06proto3'
    ),
)


_REQUEST = _descriptor.Descriptor(
    name="Request",
    full_name="common.Request",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="id",
            full_name="common.Request.id",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="type",
            full_name="common.Request.type",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="in1",
            full_name="common.Request.in1",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="in2",
            full_name="common.Request.in2",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="in3",
            full_name="common.Request.in3",
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="in4",
            full_name="common.Request.in4",
            index=5,
            number=6,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="in5",
            full_name="common.Request.in5",
            index=6,
            number=7,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="extra",
            full_name="common.Request.extra",
            index=7,
            number=8,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=24,
    serialized_end=139,
)


_RESPONSE = _descriptor.Descriptor(
    name="Response",
    full_name="common.Response",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="request_id",
            full_name="common.Response.request_id",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="success",
            full_name="common.Response.success",
            index=1,
            number=2,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="msg",
            full_name="common.Response.msg",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="out1",
            full_name="common.Response.out1",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="out2",
            full_name="common.Response.out2",
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="out3",
            full_name="common.Response.out3",
            index=5,
            number=6,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="out4",
            full_name="common.Response.out4",
            index=6,
            number=7,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="out5",
            full_name="common.Response.out5",
            index=7,
            number=8,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=142,
    serialized_end=272,
)

DESCRIPTOR.message_types_by_name["Request"] = _REQUEST
DESCRIPTOR.message_types_by_name["Response"] = _RESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Request = _reflection.GeneratedProtocolMessageType(
    "Request",
    (_message.Message,),
    dict(
        DESCRIPTOR=_REQUEST,
        __module__="common_pb2"
        # @@protoc_insertion_point(class_scope:common.Request)
    ),
)
_sym_db.RegisterMessage(Request)

Response = _reflection.GeneratedProtocolMessageType(
    "Response",
    (_message.Message,),
    dict(
        DESCRIPTOR=_RESPONSE,
        __module__="common_pb2"
        # @@protoc_insertion_point(class_scope:common.Response)
    ),
)
_sym_db.RegisterMessage(Response)


DESCRIPTOR._options = None

_COMMON = _descriptor.ServiceDescriptor(
    name="Common",
    full_name="common.Common",
    file=DESCRIPTOR,
    index=0,
    serialized_options=None,
    serialized_start=274,
    serialized_end=383,
    methods=[
        _descriptor.MethodDescriptor(
            name="predict",
            full_name="common.Common.predict",
            index=0,
            containing_service=None,
            input_type=_REQUEST,
            output_type=_RESPONSE,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name="predictAsync",
            full_name="common.Common.predictAsync",
            index=1,
            containing_service=None,
            input_type=_REQUEST,
            output_type=_RESPONSE,
            serialized_options=None,
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_COMMON)

DESCRIPTOR.services_by_name["Common"] = _COMMON

# @@protoc_insertion_point(module_scope)
